// types/games/turtlesoup.ts
/**
 * 海龟汤游戏状态
 */
export enum TurtleSoupGameStatus {
  CREATED = 'created',      // 已创建
  WAITING = 'waiting',      // 等待开始
  ACTIVE = 'active',        // 进行中
  COMPLETED = 'completed',  // 已完成
  ABANDONED = 'abandoned'   // 已放弃
}

/**
 * 海龟汤游戏难度
 */
export enum TurtleSoupDifficulty {
  EASY = 'easy',
  MEDIUM = 'medium',
  HARD = 'hard'
}

/**
 * 海龟汤主题类型
 */
export enum TurtleSoupThemeType {
  BASIC = 'basic',          // 基础主题（免费）
  PREMIUM = 'premium'       // 特色主题（付费）
}

/**
 * 游戏主题
 */
export interface TurtleSoupTheme {
  themeId: string;                // 主题ID
  name: string;                   // 主题名称
  description: string;            // 主题描述
  type: TurtleSoupThemeType;      // 主题类型
  price?: number;                 // 价格（如果是付费主题）
  isNew?: boolean;                // 是否为新主题
  isLocked?: boolean;             // 是否锁定（需要购买）
}

/**
 * 游戏题目
 */
export interface TurtleSoupPuzzle {
  puzzleId: string;                // 题目ID
  themeId: string;                // 主题ID
  title: string;                  // 题目标题
  scenario: string;            // 汤面
  truth: string;                  // 汤底
  keyClues: string[];       // 关键线索
  hints: {
    keyword: string;              // 提示关键词，初级道具
    sentence: string;             // 提示句子，高级道具
  }[];
  difficulty: TurtleSoupDifficulty; // 题目难度
  averageDuration: number;        // 平均完成时间（分钟）
  price?: number;                  // 价格
  isNew?: boolean;                // 是否为新题目
  isLocked?: boolean;             // 是否锁定（需要购买）
}

/**
 * 游戏设置
 */
export interface TurtleSoupGameSettings {
  themeId: string;                // 选择的主题ID
  puzzleId: string;               // 选择的题目ID
  difficulty: TurtleSoupDifficulty; // 游戏难度
  maxPlayers: number;             // 最大玩家数
  password?: string;              // 房间密码
}

/**
 * 游戏基础视图
 */
interface TurtleSoupGameBaseView {
  gameId: string;
  roomId: string;
  title: string;
  theme: TurtleSoupTheme;
  puzzle: TurtleSoupPuzzle;
  status: TurtleSoupGameStatus;
  startTime?: number;
  currentTime?: number;
  duration?: number;
  hostId: string;
  hostName: string;
  progress: number;
  difficulty: TurtleSoupDifficulty;
  settings: TurtleSoupGameSettings;
}

/**
 * 游戏主持人视图
 */
export interface TurtleSoupGameHostView extends TurtleSoupGameBaseView {
  players: {
    userId: string;
    name: string;
    avatar?: string;
    joinedAt: number;
    questionCount: number;
  }[];
}

export interface TurtleSoupGamePlayerView extends TurtleSoupGameBaseView {
  myPlayerInfo: {
    userId: string;
    name: string;
    avatar?: string;
    joinedAt: number;
    questionCount: number;
  };
  otherPlayers: {
    userId: string;
    name: string;
    avatar?: string;
  }[];
}